summaryrefslogtreecommitdiffstats
path: root/build/update.sh
diff options
context:
space:
mode:
Diffstat (limited to 'build/update.sh')
-rwxr-xr-xbuild/update.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/build/update.sh b/build/update.sh
index 3a3d2eac5dc..4aad7edb7c4 100755
--- a/build/update.sh
+++ b/build/update.sh
@@ -1,15 +1,15 @@
#!/bin/bash
# Update Nextcloud server and apps from latest git master
# For local development environment
# Use from Nextcloud server folder with `./build/update.sh`
# Update server
printf "\n\033[1m${PWD##*/}\033[0m\n"
-git checkout master
+git checkout stable29
git pull --quiet -p
git --no-pager log -3 --pretty=format:"%h %Cblue%ar%x09%an %Creset%s"
printf "\n"
-git branch --merged master | grep -v "master$" | xargs git branch -d
+git branch --merged stable29 | grep -v "stable29$" | xargs git branch -d
git submodule update --init
# Update apps
@@ -1,15 +1,15 @@
#!/bin/bash
-# Update Nextcloud server and apps from latest git master
+# Update Nextcloud server and apps from latest git stable29
# For local development environment
# Use from Nextcloud server folder with `./build/update.sh`